.. currentmodule:: pvlib

Spectrum
--------

.. autosummary::
   :toctree: ../generated/

   spectrum.spectrl2
   spectrum.get_example_spectral_response
   spectrum.get_am15g
   spectrum.calc_spectral_mismatch_field
